@@ -14,7 +14,7 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-import traceback
+import traceback, sys
 
 import pyrunner.logger.file as lg
 
@@ -57,6 +57,9 @@ class Worker(ABC):
     methods, if defined.
     """
     
+    sys.stdout = open(self.logfile, 'a')
+    sys.stderr = open(self.logfile, 'a')
+    
     # RUN
     try:
       self.retcode = self.run() or self.retcode
